<?php

namespace Drupal\seo_analyzer\Metric\Page;

use Drupal\seo_analyzer\Metric\AbstractMetric;

class AltsMetric extends AbstractMetric {
  public $description = 'Alternate texts for images';

  /**
   * @inheritdoc
   */
  public function analyze(): string {
    $this->description = $this->t('Alternate texts for images');
    if (empty($this->value)) {
      return $this->t('There is nothing to do here as there is no images on the site.');
    }
    $imagesCount = count($this->value);
    $altsCount = count(array_filter($this->value));
    $emptyAlts = $imagesCount - $altsCount;
    switch (TRUE) {
      case ($emptyAlts > 10):
        $this->impact = 5;
        $message = $this->t('There is a lot of images without alternate texts on your site. Every image should be described with alt attribute');
        break;
      case ($emptyAlts > 0):
        $this->impact = 3;
        $message = $this->t('You should optimise your site adding missing alt descriptions to images, as this could have strong impact on SEO');
        break;
      default:
        $message = $this->t('Good! All images on site have alternate descriptions');
        break;
    }
    return $message;
  }
}
